---
navigation: true
title: RAID
main:
  fluid: false
---
:ellipsis{left=0px width=40rem top=10rem blur=140px}
# RAID

_Ensemble Redondant de Disques Indépendants_

::alert{type="info"}
🎯 __Objectifs :__
- Comprendre ce qu'est un système RAID
- Comprendre quel type de RAID est adapté aux différents usages
::

En informatique, le RAID (Redundant Array of Independent Disks) est un système permettant de combiner plusieurs disques durs pour améliorer les performances et/ou la fiabilité. Il fonctionne en restructurant et en répartissant les blocs de données entre les disques.

À l’origine, les systèmes RAID étaient matériels, ce qui signifiait qu’un contrôleur dédié (une puce spécifique) gérait la distribution des données et les opérations RAID. Aujourd’hui, la plupart des systèmes RAID (ou équivalents) sont logiciels. En fait, de nombreuses technologies logicielles peuvent créer des systèmes de type RAID avec des fonctionnalités indisponibles dans les RAID matériels, comme la réparation automatique (data scrubbing), les instantanés (snapshots), etc.

## Différents types de RAID

Il existe plusieurs types de RAID, chacun ayant ses avantages et inconvénients. Les facteurs qui les influencent sont les suivants :

- Nombre de disques
- Capacité totale de stockage
- Vitesse de lecture
- Vitesse d’écriture
- Tolérance aux pannes (résistance aux défaillances matérielles)

::alert{type="warning"}
:::list{type="warning"}
  - Le RAID n’est pas un système de sauvegarde mais un système de continuité de service ! Il permet seulement le remplacement à chaud des disques sans interruption du serveur ou restauration depuis une sauvegarde. Vous avez toujours besoin d’un système de sauvegarde externe.
:::

### Sans RAID
---

<div style="display: flex; align-items: center;">
  <img src="/img/global/no-raid.svg" alt="Image" style="max-width: 30%; max-height:230px; margin-right: 20px;">
  <ul>
    <li>Vos disques sans RAID. Les données sont stockées disque par disque.</li>
    <li>Si vous perdez un disque, seules ses données sont perdues.</li>
    <li>La capacité totale est la somme de tous les disques.</li>
</div>

Utilisez vos disques sans RAID si vous n’avez pas peur de perdre des données et pouvez tolérer une interruption de service entre la panne et la restauration.

### RAID 0
---

<div style="display: flex; align-items: center;">
  <img src="/img/global/raid0.svg" alt="Image" style="max-width: 30%; max-height:230px; margin-right: 20px;">
  <ul>
    <li>Le système voit un seul disque.</li>
    <li>Les données sont entrelacées entre tous les disques.</li>
    <li>Si un disque est perdu, toutes les données le sont.</li>
    <li>Excellentes performances en lecture et écriture (multipliées par le nombre de disques).</li>
    <li>La capacité totale est la somme de tous les disques.</li>
    <li>Minimum de 2 disques requis.</li>
</div>

Utilisez RAID 0 si vous souhaitez privilégier la performance et que la perte de données n’est pas un problème. Idéal pour le stockage temporaire à haute vitesse (montage vidéo, IA, etc). Pas adapté au stockage à long terme.

### RAID 1
---

<div style="display: flex; align-items: center;">
  <img src="/img/global/raid1.svg" alt="Image" style="max-width: 30%; max-height:230px; margin-right: 20px;">
  <ul>
    <li>Le système voit un seul disque.</li>
    <li>Tous les disques contiennent les mêmes données.</li>
    <li>Vous pouvez perdre tous les disques tant qu'un seul est en bonne santé.</li>
    <li>Vitesse de lecture améliorée (selon le nombre de disques).</li>
    <li>Capacité totale égale à un seul disque (ex. : 2×10 To = 10 To).</li>
    <li>Minimum de 2 disques requis.</li>
</div>

Utilisez RAID 1 pour une redondance maximale. Chaque disque contient toutes les données, donc les performances ne sont pas affectées en cas de panne. Une fois les disques remplacés, les données sont rapidement restaurées. Mais la capacité utilisable est limitée à un seul disque, ce qui en fait une solution coûteuse.

::alert{type="success"}
:::list{type="success"}
- __Astuce :__ Vous pouvez combiner le RAID 1 avec d’autres types de RAID pour créer des grappes miroir.
:::
::

### RAID 5
---
<p align="center">
  <img src="/img/global/raid5.svg" alt="Image" style="max-width: 40%; margin-right: 20px;">
</p>

- Le système voit un seul disque.
- Les données sont entrelacées avec des blocs de parité.
- Vous pouvez perdre un disque et récupérer les données.
- Vitesse de lecture améliorée (selon le nombre de disques).
- Capacité totale = somme des disques – 1 (ex. : 3×10 To = 20 To).
- Minimum de 3 disques (4 recommandés pour limiter la perte de capacité).

Utilisez RAID 5 pour un stockage fiable avec 3 à 5 disques et une perte minimale d’espace. Il tolère une panne, mais la reconstruction peut durer plusieurs jours avec des performances dégradées.

### RAID 6
---
<p align="center">
  <img src="/img/global/raid6.svg" alt="Image" style="max-width: 50%; margin-right: 20px;">
</p>

- Le système voit un seul disque.
- Les données sont entrelacées avec deux blocs de parité.
- Vous pouvez perdre 2 disques et récupérer les données.
- Vitesse de lecture améliorée (selon le nombre de disques).
- Capacité totale = somme des disques – 2 (ex. : 4×10 To = 20 To).
- Minimum de 4 disques (6 recommandés pour minimiser la perte d’espace).

Utilisez RAID 6 dans les mêmes cas que RAID 5, surtout avec 6 disques ou plus. Plus de disques = plus de risque de panne. RAID 6 vous apportera plus de fiabilité en cas de panne simultanée de deux disques. Il n'y a rien de plus frustrant que de perdre un second disque en pleine reconstruction du remplacement du premier.